===============================================
 oslo.db -- OpenStack Database Pattern Library
===============================================

The oslo.db (database) handling library, provides database
connectivity to different database backends and various other helper
utils.

.. toctree::
   :maxdepth: 2

   installation
   opts
   usage
   contributing
   history

API Documentation
=================

.. toctree::
   :maxdepth: 1

   api/autoindex

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
